@@ -216,7 +216,7 @@ class User(NeolibBase):
             raise NoActiveNeopet('Missing active pet')
 
         # Return if it was successful
-        return self.username in pg.content
+        return pg.response.url == 'http://www.neopets.com/'
 
     def get_page(self, url, post_data='', header_values=''):
         """A wrapper function that returns a page using the user's session
